@@ -12,13 +12,12 @@ echo "Starting container creation ..."
 if [[ "${_RUNNING_ARCH}" == "aarch64" ]]; then
     _prepare_pacman "${1}" || exit 1
     _install_base_packages "${1}" || exit 1
-    _clean_mkinitcpio "${1}" || exit 1
-    _clean_cache "${1}" || exit 1
+    _clean_mkinitcpio "${1}"
+    _clean_cache "${1}"
     _install_archboot "${1}" || exit 1
     _umount_special "${1}" || exit 1
-    _generate_locales "${1}" || exit 1
-    _clean_locale "${1}"
-    _clean_container "${1}" || exit 1
+    _generate_locales "${1}"
+    _clean_container "${1}"
     _clean_archboot_cache
     _generate_keyring "${1}" || exit 1
     _copy_mirrorlist_and_pacman_conf "${1}"
@@ -27,14 +26,13 @@ fi
 if [[ "${_RUNNING_ARCH}" == "x86_64" ]]; then
     _aarch64_pacman_chroot "${1}" || exit 1
     _aarch64_install_base_packages "${1}" || exit 1
-    _clean_mkinitcpio "${1}" || exit 1
-    _clean_cache "${1}" || exit 1
+    _clean_mkinitcpio "${1}"
+    _clean_cache "${1}"
     _aarch64_install_archboot "${1}" || exit 1
-    _clean_mkinitcpio "${1}" || exit 1
-    _clean_cache "${1}" || exit 1
-    _generate_locales "${1}" || exit 1
-    _clean_locale "${1}"
-    _clean_container "${1}" || exit 1
+    _clean_mkinitcpio "${1}"
+    _clean_cache "${1}"
+    _generate_locales "${1}"
+    _clean_container "${1}" 2>/dev/null
 fi
 _reproducibility "${1}"
 _set_hostname "${1}" || exit 1
