@@ -11,10 +11,10 @@ _prepare_shim_files || exit 1
 _upload_efi_files shim-fedora || exit 1
 _cleanup shim-fedora || exit 1
 mkdir -m 777 grub-efi
-_prepare_uefi_X64_GRUB_USB_files || exit 1
-_prepare_uefi_IA32_GRUB_USB_files || exit 1
+_prepare_uefi_X64 || exit 1
+_prepare_uefi_IA32 || exit 1
 archboot-aarch64-create-container.sh grub-aarch64
-_prepare_uefi_AA64_GRUB_USB_files || exit 1
+_prepare_uefi_AA64 || exit 1
 _cleanup grub-aarch64 || exit 1
 _upload_efi_files grub-efi
 _cleanup grub-efi || exit 1
