@@ -7,7 +7,7 @@ _L_INSTALL_COMPLETE=""
 _G_RELEASE=""
 _CONFIG="/etc/archboot/${_RUNNING_ARCH}-update_installer.conf"
 _W_DIR="/archboot"
-_INSTALLER_SOURCE="https://gitlab.archlinux.org/tpowa/archboot/-/raw/master/usr/bin"
+_INSTALLER_SOURCE="https://gitlab.archlinux.org/tpowa/archboot/-/raw/master"
 
 kver() {
     # get kernel version from installed kernel
@@ -64,18 +64,18 @@ fi
 # Download latest setup and quickinst script from git repository
 if [[ "${_D_SCRIPTS}" == "1" ]]; then
     echo "Downloading latest km, tz, quickinst, setup and helpers..."
-    wget -q "$_INSTALLER_SOURCE/archboot-quickinst.sh?inline=false" -O /usr/bin/quickinst >/dev/null 2>&1
-    wget -q "$_INSTALLER_SOURCE/archboot-setup.sh?inline=false" -O /usr/bin/setup >/dev/null 2>&1
-    wget -q "$_INSTALLER_SOURCE/archboot-km.sh?inline=false" -O /usr/bin/km >/dev/null 2>&1
-    wget -q "$_INSTALLER_SOURCE/archboot-tz.sh?inline=false" -O /usr/bin/tz >/dev/null 2>&1
-    wget -q "$_INSTALLER_SOURCE/archboot-${_RUNNING_ARCH}-create-container.sh?inline=false" -O "/usr/bin/archboot-${_RUNNING_ARCH}-create-container.sh" >/dev/null 2>&1
-    wget -q "$_INSTALLER_SOURCE/archboot-${_RUNNING_ARCH}-release.sh?inline=false" -O "/usr/bin/archboot-${_RUNNING_ARCH}-release.sh" >/dev/null 2>&1
-    wget -q "$_INSTALLER_SOURCE/archboot-binary-check.sh?inline=false" -O /usr/bin/archboot-binary-check.sh >/dev/null 2>&1
-    wget -q "$_INSTALLER_SOURCE/archboot-update-installer.sh?inline=false" -O /usr/bin/update-installer.sh >/dev/null 2>&1
-    wget -q "$_INSTALLER_SOURCE/functions?inline=false" -O "/usr/lib/archboot/functions" >/dev/null 2>&1
-    wget -q "$_INSTALLER_SOURCE/container_functions?inline=false" -O "/usr/lib/archboot/container_functions" >/dev/null 2>&1
-    wget -q "$_INSTALLER_SOURCE/release_functions?inline=false" -O "/usr/lib/archboot/release_functions" >/dev/null 2>&1
-    wget -q "$_INSTALLER_SOURCE/iso_functions?inline=false" -O "/usr/lib/archboot/iso_functions" >/dev/null 2>&1
+    wget -q "$_INSTALLER_SOURCE/usr/bin/archboot-quickinst.sh?inline=false" -O /usr/bin/quickinst >/dev/null 2>&1
+    wget -q "$_INSTALLER_SOURCE/usr/bin/archboot-setup.sh?inline=false" -O /usr/bin/setup >/dev/null 2>&1
+    wget -q "$_INSTALLER_SOURCE/usr/bin/archboot-km.sh?inline=false" -O /usr/bin/km >/dev/null 2>&1
+    wget -q "$_INSTALLER_SOURCE/usr/bin/archboot-tz.sh?inline=false" -O /usr/bin/tz >/dev/null 2>&1
+    wget -q "$_INSTALLER_SOURCE/usr/bin/archboot-${_RUNNING_ARCH}-create-container.sh?inline=false" -O "/usr/bin/archboot-${_RUNNING_ARCH}-create-container.sh" >/dev/null 2>&1
+    wget -q "$_INSTALLER_SOURCE/usr/bin/archboot-${_RUNNING_ARCH}-release.sh?inline=false" -O "/usr/bin/archboot-${_RUNNING_ARCH}-release.sh" >/dev/null 2>&1
+    wget -q "$_INSTALLER_SOURCE/usr/bin/archboot-binary-check.sh?inline=false" -O /usr/bin/archboot-binary-check.sh >/dev/null 2>&1
+    wget -q "$_INSTALLER_SOURCE/usr/bin/archboot-update-installer.sh?inline=false" -O /usr/bin/update-installer.sh >/dev/null 2>&1
+    wget -q "$_INSTALLER_SOURCE/usr/lib/archboot/functions?inline=false" -O "/usr/lib/archboot/functions" >/dev/null 2>&1
+    wget -q "$_INSTALLER_SOURCE/usr/lib/archboot/container_functions?inline=false" -O "/usr/lib/archboot/container_functions" >/dev/null 2>&1
+    wget -q "$_INSTALLER_SOURCE/usr/lib/archboot/release_functions?inline=false" -O "/usr/lib/archboot/release_functions" >/dev/null 2>&1
+    wget -q "$_INSTALLER_SOURCE/usr/lib/archboot/iso_functions?inline=false" -O "/usr/lib/archboot/iso_functions" >/dev/null 2>&1
     echo "Finished: Downloading scripts done."
     exit 0
 fi
@@ -84,13 +84,19 @@ echo "Information: Logging is done on /dev/tty7 ..."
 
 # Generate new environment and launch it with kexec
 if [[ "${_L_COMPLETE}" == "1" || "${_L_INSTALL_COMPLETE}" == "1" ]]; then
+    if [[ -f /.update-installer ]]; then
+        echo "Aborting: update-installer.sh is already running on other tty ..."
+        echo "If you are absolutly sure it's not running, you need to remove /.update-installer"
+        exit 0
+    fi
+    touch /.update-installer
     # remove everything not necessary
     echo "Step 1/8: Removing not necessary files from / ..."
     [[ -d "/usr/lib/firmware" ]] && rm -r "/usr/lib/firmware"
     [[ -d "/usr/lib/modules" ]] && rm -r "/usr/lib/modules"
     _SHARE_DIRS="efitools file grub hwdata kbd licenses makepkg nmap openvpn pacman refind tc usb_modeswitch vim zoneinfo zsh"
     for i in ${_SHARE_DIRS}; do
-        #sheclcheck disable=SC2115
+        #shellcheck disable=SC2115
         [[ -d "/usr/share/${i}" ]] && rm -r "/usr/share/${i}"
     done
     echo "Step 2/8: Generating archboot container in ${_W_DIR} ..."
