@@ -14,13 +14,12 @@ echo "Starting container creation ..."
 _create_pacman_conf "${1}"
 _prepare_pacman "${1}" || exit 1
 _install_base_packages "${1}" || exit 1
-_clean_mkinitcpio "${1}" || exit 1
-_clean_cache "${1}" || exit 1
+_clean_mkinitcpio "${1}"
+_clean_cache "${1}"
 _install_archboot "${1}" || exit 1
 _umount_special "${1}" || exit 1
-_generate_locales "${1}" || exit 1
-_clean_locale "${1}"
-_clean_container "${1}" || exit 1
+_generate_locales "${1}"
+_clean_container "${1}"
 _clean_archboot_cache
 _generate_keyring "${1}" || exit 1
 _copy_mirrorlist_and_pacman_conf "${1}"
