@@ -13,8 +13,9 @@ _prepare_kernel_initramfs_files || exit 1
 _prepare_fedora_shim_bootloaders_x86_64 || exit 1
 _prepare_uefi_shell_tianocore || exit 1
 _prepare_efitools_uefi || exit 1
-_prepare_uefi_X64_GRUB_USB_files || exit 1
-_prepare_uefi_IA32_GRUB_USB_files || exit 1
+_prepare_uefi_X64 || exit 1
+_prepare_uefi_IA32 || exit 1
+_prepare_background || exit 1
 _reproducibility
 _prepare_uefi_image || exit 1
 _reproducibility
